<?php

/**
 * @file
 * Settings page callback file for the visitors module.
 */

/**
 * Create visitors settings form.
 *
 * @return array
 *   The form.
 */
function visitors_admin_settings() {

  $form = array();

  $form['visitors_lines_per_page'] = array(
    '#type' => 'select',
    '#title' => 'Lines per page',
    '#default_value' => variable_get('visitors_lines_per_page', 10),
    '#options' => array(
      5 => 5,
      10 => 10,
      25 => 25,
      50 => 50,
      100 => 100,
      200 => 200,
      250 => 250,
      500 => 500,
      1000 => 1000,
    ),
    '#description' => t('The default maximum number of lines to display per page.'),
  );

  $period = drupal_map_assoc(
    array(
      3600,
      10800,
      21600,
      32400,
      43200,
      86400,
      172800,
      259200,
      604800,
      1209600,
      2419200,
      4838400,
      9676800,
      31536000,
    ),
      'format_interval'
    );
  $period[0] = t('Never');

  $form['visitors_flush_log_timer'] = array(
    '#type' => 'select',
    '#title' => t('Discard visitors logs older than'),
    '#default_value'   => variable_get('visitors_flush_log_timer', 0),
    '#options' => $period,
    '#description' =>
    t('Older visitors log entries (including referrer statistics) will be automatically discarded. (Requires a correctly configured <a href="@cron">cron maintenance task</a>.)',
        array('@cron' => url('admin/reports/status'))
    ),
  );

  $installed = array_filter(list_themes(), function ($obj) {
    return $obj->status;
  });

  $themes = array('_admin' => t('admin'), '_default' => t('default')) + array_map(function ($value) {
    return $value->name;
  }, $installed);

  $form['visitors_theme'] = array(
    '#title' => t('Theme'),
    '#description' => t('Select a theme for the Visitors reports.'),
    '#type' => 'select',
    '#options' => $themes,
    '#default_value' => variable_get('visitors_theme', '_admin'),
  );

  $default_role_options = [];
  foreach (user_roles() as $role) {
    $default_role_options[$role] = ucwords($role);
  }

  $form['visibility_title'] = array(
    '#type' => 'item',
    '#title' => t('Logging settings'),
  );
  $form['logging'] = array(
    '#type' => 'vertical_tabs',
    '#weight' => 20,
    '#attached' => array(
      'js' => array(drupal_get_path('module', 'visitors') . '/form.js'),
    ),
  );

  // Per-path visibility.
  $form['logging']['path'] = array(
    '#type' => 'fieldset',
    '#title' => t('Pages'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
    '#group' => 'visibility',
    '#weight' => 0,
  );
  $access = user_access('use PHP for settings');
  if (isset($block->visibility) && $block->visibility == VISITORS_VISIBILITY_PHP && !$access) {
    $form['logging']['path']['visitors_visibility_pages'] = array(
      '#type' => 'value',
      '#value' => VISITORS_VISIBILITY_PHP,
    );
    $form['logging']['path']['visitors_excluded_pages'] = array(
      '#type' => 'value',
      '#value' => isset($block->pages) ? $block->pages : '',
    );
  }
  else {
    $options = array(
      VISITORS_VISIBILITY_NOTLISTED => t('All pages except those listed'),
      VISITORS_VISIBILITY_LISTED => t('Only the listed pages'),
    );
    $description = t("Specify pages by using their paths. Enter one path per line. The '*' character is a wildcard. Example paths are %blog for the blog page and %blog-wildcard for every personal blog. %front is the front page.", array('%blog' => 'blog', '%blog-wildcard' => 'blog/*', '%front' => '<front>'));

    if (module_exists('php') && $access) {
      $options += array(VISITORS_VISIBILITY_PHP => t('Pages on which this PHP code returns <code>TRUE</code> (experts only)'));
      $title = t('Pages or PHP code');
      $description .= ' ' . t('If the PHP option is chosen, enter PHP code between %php. Note that executing incorrect PHP code can break your Drupal site.', array('%php' => '<?php ?>'));
    }
    else {
      $title = t('Pages');
    }
    $form['logging']['path']['visitors_visibility_pages'] = array(
      '#type' => 'radios',
      '#title' => t('Log visits on specific pages'),
      '#options' => $options,
      '#default_value' => variable_get('visitors_visibility_pages', VISITORS_VISIBILITY_NOTLISTED),
    );
    $form['logging']['path']['visitors_excluded_pages'] = array(
      '#type' => 'textarea',
      '#title' => '<span class="element-invisible">' . $title . '</span>',
      '#default_value' => variable_get('visitors_excluded_pages', ''),
      '#description' => $description,
    );
  }

  $role_options = array_map('check_plain', user_roles());
  $form['logging']['role'] = array(
    '#type' => 'fieldset',
    '#title' => t('Roles'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
    '#group' => 'visibility',
    '#weight' => 10,
  );
  $form['logging']['role']['visitors_excluded_roles'] = array(
    '#type' => 'checkboxes',
    '#title' => t('Exclude visits for specific roles'),
    '#default_value' => variable_get('visitors_excluded_roles', []),
    '#options' => $default_role_options,
    '#description' => t('Exclude visits for the selected role(s).'),
  );

  // Per-user visibility.
  $form['logging']['user'] = array(
    '#type' => 'fieldset',
    '#title' => t('Users'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
    '#group' => 'visibility',
    '#weight' => 20,
  );

  $form['logging']['user']['visitors_exclude_user1'] = array(
    '#type' => 'checkbox',
    '#title' => t('Exclude user1 from statistics'),
    '#default_value' => variable_get('visitors_exclude_user1', 0),
    '#description' => t('Exclude hits of user1 from statistics.'),
  );

  // Chart settings.
  $form['chart'] = array(
    '#type' => 'fieldset',
    '#title' => t('Chart settings'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
    '#group' => 'visibility',
    '#weight' => 30,
    '#description' => t('Visitors chart settings'),
  );

  $form['chart']['visitors_chart_width'] = array(
    '#type' => 'textfield',
    '#title' => t('Width'),
    '#default_value' => variable_get('visitors_chart_width', 700),
    '#description' => t('Chart width.'),
  );

  $form['chart']['visitors_chart_height'] = array(
    '#type' => 'textfield',
    '#title' => t('Height'),
    '#default_value' => variable_get('visitors_chart_height', 430),
    '#description' => t('Chart height.'),
  );

  return system_settings_form($form);
}
